@@ -5,7 +5,7 @@ from tqatest.app.core.errors import PredictException, ModelLoadException
 # from anscenter.app.core.config import MODEL_NAME, MODEL_PATH, MODEL_ID
 from loguru import logger
 from tqatest.ml.libs import annhub
-from importlib.resources import read_text
+from importlib.resources import path
 
 MODEL_NAME = "TrainedModel_c++.ann"
 MODEL_PATH = "ml/model/"
@@ -28,12 +28,12 @@ class MachineLearningModel(object):
         #     message = f"Machine learning model at {path} not exists!"
         #     logger.error(message)
         #     raise FileNotFoundError(message)
-        path = read_text("tqatest.ml.model", "TrainedModel_c++.ann")
-        self.load_model(path)
+        mypath = path("tqatest.ml.model", "TrainedModel_c++.ann")
+        self.load_model(mypath)
     
-    def load_model(self, path : str):
+    def load_model(self, mypath : str):
         self.model = annhub.ANNHUB(int(MODEL_ID))
-        self.model.LoadWeightFile(path)
+        self.model.LoadWeightFile(mypath)
         if not self.model:
             message = f"Model {MODEL_ID} could not load!"
             logger.error(message)
